@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -33,6 +33,7 @@ except AttributeError:  # pragma: NO COVER
 
 from google.cloud.monitoring_dashboard_v1.services.dashboards_service import pagers
 from google.cloud.monitoring_dashboard_v1.types import dashboard
+from google.cloud.monitoring_dashboard_v1.types import dashboard_filter
 from google.cloud.monitoring_dashboard_v1.types import dashboards_service
 from google.cloud.monitoring_dashboard_v1.types import layouts
 from .transports.base import DashboardsServiceTransport, DEFAULT_CLIENT_INFO
@@ -226,14 +227,13 @@ class DashboardsServiceAsyncClient:
         permissions, see `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
-
         .. code-block:: python
 
             from google.monitoring import dashboard_v1
 
-            def sample_create_dashboard():
+            async def sample_create_dashboard():
                 # Create a client
-                client = dashboard_v1.DashboardsServiceClient()
+                client = dashboard_v1.DashboardsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 dashboard = dashboard_v1.Dashboard()
@@ -245,7 +245,7 @@ class DashboardsServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_dashboard(request=request)
+                response = await client.create_dashboard(request=request)
 
                 # Handle the response
                 print(response)
@@ -285,7 +285,12 @@ class DashboardsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -305,14 +310,13 @@ class DashboardsServiceAsyncClient:
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
-
         .. code-block:: python
 
             from google.monitoring import dashboard_v1
 
-            def sample_list_dashboards():
+            async def sample_list_dashboards():
                 # Create a client
-                client = dashboard_v1.DashboardsServiceClient()
+                client = dashboard_v1.DashboardsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = dashboard_v1.ListDashboardsRequest(
@@ -323,7 +327,7 @@ class DashboardsServiceAsyncClient:
                 page_result = client.list_dashboards(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -361,12 +365,20 @@ class DashboardsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListDashboardsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -387,14 +399,13 @@ class DashboardsServiceAsyncClient:
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
-
         .. code-block:: python
 
             from google.monitoring import dashboard_v1
 
-            def sample_get_dashboard():
+            async def sample_get_dashboard():
                 # Create a client
-                client = dashboard_v1.DashboardsServiceClient()
+                client = dashboard_v1.DashboardsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = dashboard_v1.GetDashboardRequest(
@@ -402,7 +413,7 @@ class DashboardsServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_dashboard(request=request)
+                response = await client.get_dashboard(request=request)
 
                 # Handle the response
                 print(response)
@@ -442,7 +453,12 @@ class DashboardsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -462,14 +478,13 @@ class DashboardsServiceAsyncClient:
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
-
         .. code-block:: python
 
             from google.monitoring import dashboard_v1
 
-            def sample_delete_dashboard():
+            async def sample_delete_dashboard():
                 # Create a client
-                client = dashboard_v1.DashboardsServiceClient()
+                client = dashboard_v1.DashboardsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = dashboard_v1.DeleteDashboardRequest(
@@ -477,7 +492,7 @@ class DashboardsServiceAsyncClient:
                 )
 
                 # Make the request
-                client.delete_dashboard(request=request)
+                await client.delete_dashboard(request=request)
 
         Args:
             request (Union[google.cloud.monitoring_dashboard_v1.types.DeleteDashboardRequest, dict]):
@@ -507,7 +522,10 @@ class DashboardsServiceAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def update_dashboard(
@@ -525,14 +543,13 @@ class DashboardsServiceAsyncClient:
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
-
         .. code-block:: python
 
             from google.monitoring import dashboard_v1
 
-            def sample_update_dashboard():
+            async def sample_update_dashboard():
                 # Create a client
-                client = dashboard_v1.DashboardsServiceClient()
+                client = dashboard_v1.DashboardsServiceAsyncClient()
 
                 # Initialize request argument(s)
                 dashboard = dashboard_v1.Dashboard()
@@ -543,7 +560,7 @@ class DashboardsServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.update_dashboard(request=request)
+                response = await client.update_dashboard(request=request)
 
                 # Handle the response
                 print(response)
@@ -585,7 +602,12 @@ class DashboardsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
