@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -36,6 +36,7 @@ except AttributeError:  # pragma: NO COVER
 
 from google.cloud.monitoring_dashboard_v1.services.dashboards_service import pagers
 from google.cloud.monitoring_dashboard_v1.types import dashboard
+from google.cloud.monitoring_dashboard_v1.types import dashboard_filter
 from google.cloud.monitoring_dashboard_v1.types import dashboards_service
 from google.cloud.monitoring_dashboard_v1.types import layouts
 from .transports.base import DashboardsServiceTransport, DEFAULT_CLIENT_INFO
@@ -58,7 +59,8 @@ class DashboardsServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = DashboardsServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[DashboardsServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -166,10 +168,14 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def alert_policy_path(project: str, alert_policy: str,) -> str:
+    def alert_policy_path(
+        project: str,
+        alert_policy: str,
+    ) -> str:
         """Returns a fully-qualified alert_policy string."""
         return "projects/{project}/alertPolicies/{alert_policy}".format(
-            project=project, alert_policy=alert_policy,
+            project=project,
+            alert_policy=alert_policy,
         )
 
     @staticmethod
@@ -181,10 +187,14 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def dashboard_path(project: str, dashboard: str,) -> str:
+    def dashboard_path(
+        project: str,
+        dashboard: str,
+    ) -> str:
         """Returns a fully-qualified dashboard string."""
         return "projects/{project}/dashboards/{dashboard}".format(
-            project=project, dashboard=dashboard,
+            project=project,
+            dashboard=dashboard,
         )
 
     @staticmethod
@@ -194,7 +204,9 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -207,9 +219,13 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -218,9 +234,13 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -229,9 +249,13 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -240,10 +264,14 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -433,7 +461,6 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         permissions, see `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
-
         .. code-block:: python
 
             from google.monitoring import dashboard_v1
@@ -493,7 +520,12 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -513,7 +545,6 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
-
         .. code-block:: python
 
             from google.monitoring import dashboard_v1
@@ -570,12 +601,20 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListDashboardsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -596,7 +635,6 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
-
         .. code-block:: python
 
             from google.monitoring import dashboard_v1
@@ -652,7 +690,12 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -672,7 +715,6 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
-
         .. code-block:: python
 
             from google.monitoring import dashboard_v1
@@ -718,7 +760,10 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def update_dashboard(
@@ -736,7 +781,6 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         `Cloud Identity and Access
         Management <https://cloud.google.com/iam>`__.
 
-
         .. code-block:: python
 
             from google.monitoring import dashboard_v1
@@ -797,7 +841,12 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
