@@ -227,8 +227,7 @@ class DashboardsServiceGrpcTransport(DashboardsServiceTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -393,5 +392,9 @@ class DashboardsServiceGrpcTransport(DashboardsServiceTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("DashboardsServiceGrpcTransport",)
