@@ -40,12 +40,17 @@ from google.cloud.monitoring_dashboard_v1.services.dashboards_service import (
 from google.cloud.monitoring_dashboard_v1.services.dashboards_service import pagers
 from google.cloud.monitoring_dashboard_v1.services.dashboards_service import transports
 from google.cloud.monitoring_dashboard_v1.types import alertchart
+from google.cloud.monitoring_dashboard_v1.types import collapsible_group
 from google.cloud.monitoring_dashboard_v1.types import common
 from google.cloud.monitoring_dashboard_v1.types import dashboard
+from google.cloud.monitoring_dashboard_v1.types import dashboard_filter
 from google.cloud.monitoring_dashboard_v1.types import dashboards_service
 from google.cloud.monitoring_dashboard_v1.types import layouts
+from google.cloud.monitoring_dashboard_v1.types import logs_panel
 from google.cloud.monitoring_dashboard_v1.types import metrics
 from google.cloud.monitoring_dashboard_v1.types import scorecard
+from google.cloud.monitoring_dashboard_v1.types import table
+from google.cloud.monitoring_dashboard_v1.types import table_display_options
 from google.cloud.monitoring_dashboard_v1.types import text
 from google.cloud.monitoring_dashboard_v1.types import widget
 from google.cloud.monitoring_dashboard_v1.types import xychart
@@ -100,20 +105,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [DashboardsServiceClient, DashboardsServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (DashboardsServiceClient, "grpc"),
+        (DashboardsServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_dashboards_service_client_from_service_account_info(client_class):
+def test_dashboards_service_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "monitoring.googleapis.com:443"
+        assert client.transport._host == ("monitoring.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -142,23 +153,33 @@ def test_dashboards_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [DashboardsServiceClient, DashboardsServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (DashboardsServiceClient, "grpc"),
+        (DashboardsServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_dashboards_service_client_from_service_account_file(client_class):
+def test_dashboards_service_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "monitoring.googleapis.com:443"
+        assert client.transport._host == ("monitoring.googleapis.com:443")
 
 
 def test_dashboards_service_client_get_transport_class():
@@ -516,7 +537,9 @@ def test_dashboards_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -662,11 +685,16 @@ def test_dashboards_service_client_create_channel_credentials_file(
 
 
 @pytest.mark.parametrize(
-    "request_type", [dashboards_service.CreateDashboardRequest, dict,]
+    "request_type",
+    [
+        dashboards_service.CreateDashboardRequest,
+        dict,
+    ],
 )
 def test_create_dashboard(request_type, transport: str = "grpc"):
     client = DashboardsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -700,7 +728,8 @@ def test_create_dashboard_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DashboardsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -717,7 +746,8 @@ async def test_create_dashboard_async(
     request_type=dashboards_service.CreateDashboardRequest,
 ):
     client = DashboardsServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -729,7 +759,9 @@ async def test_create_dashboard_async(
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             dashboard.Dashboard(
-                name="name_value", display_name="display_name_value", etag="etag_value",
+                name="name_value",
+                display_name="display_name_value",
+                etag="etag_value",
             )
         )
         response = await client.create_dashboard(request)
@@ -752,13 +784,15 @@ async def test_create_dashboard_async_from_dict():
 
 
 def test_create_dashboard_field_headers():
-    client = DashboardsServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DashboardsServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = dashboards_service.CreateDashboardRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.create_dashboard), "__call__") as call:
@@ -772,7 +806,10 @@ def test_create_dashboard_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -785,7 +822,7 @@ async def test_create_dashboard_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = dashboards_service.CreateDashboardRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.create_dashboard), "__call__") as call:
@@ -799,15 +836,23 @@ async def test_create_dashboard_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.parametrize(
-    "request_type", [dashboards_service.ListDashboardsRequest, dict,]
+    "request_type",
+    [
+        dashboards_service.ListDashboardsRequest,
+        dict,
+    ],
 )
 def test_list_dashboards(request_type, transport: str = "grpc"):
     client = DashboardsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -836,7 +881,8 @@ def test_list_dashboards_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DashboardsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -853,7 +899,8 @@ async def test_list_dashboards_async(
     request_type=dashboards_service.ListDashboardsRequest,
 ):
     client = DashboardsServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -886,13 +933,15 @@ async def test_list_dashboards_async_from_dict():
 
 
 def test_list_dashboards_field_headers():
-    client = DashboardsServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DashboardsServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = dashboards_service.ListDashboardsRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_dashboards), "__call__") as call:
@@ -906,7 +955,10 @@ def test_list_dashboards_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -919,7 +971,7 @@ async def test_list_dashboards_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = dashboards_service.ListDashboardsRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_dashboards), "__call__") as call:
@@ -935,12 +987,16 @@ async def test_list_dashboards_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 def test_list_dashboards_pager(transport_name: str = "grpc"):
     client = DashboardsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -956,13 +1012,20 @@ def test_list_dashboards_pager(transport_name: str = "grpc"):
                 next_page_token="abc",
             ),
             dashboards_service.ListDashboardsResponse(
-                dashboards=[], next_page_token="def",
+                dashboards=[],
+                next_page_token="def",
             ),
             dashboards_service.ListDashboardsResponse(
-                dashboards=[dashboard.Dashboard(),], next_page_token="ghi",
+                dashboards=[
+                    dashboard.Dashboard(),
+                ],
+                next_page_token="ghi",
             ),
             dashboards_service.ListDashboardsResponse(
-                dashboards=[dashboard.Dashboard(), dashboard.Dashboard(),],
+                dashboards=[
+                    dashboard.Dashboard(),
+                    dashboard.Dashboard(),
+                ],
             ),
             RuntimeError,
         )
@@ -975,14 +1038,15 @@ def test_list_dashboards_pager(transport_name: str = "grpc"):
 
         assert pager._metadata == metadata
 
-        results = [i for i in pager]
+        results = list(pager)
         assert len(results) == 6
         assert all(isinstance(i, dashboard.Dashboard) for i in results)
 
 
 def test_list_dashboards_pages(transport_name: str = "grpc"):
     client = DashboardsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials, transport=transport_name,
+        credentials=ga_credentials.AnonymousCredentials,
+        transport=transport_name,
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -998,13 +1062,20 @@ def test_list_dashboards_pages(transport_name: str = "grpc"):
                 next_page_token="abc",
             ),
             dashboards_service.ListDashboardsResponse(
-                dashboards=[], next_page_token="def",
+                dashboards=[],
+                next_page_token="def",
             ),
             dashboards_service.ListDashboardsResponse(
-                dashboards=[dashboard.Dashboard(),], next_page_token="ghi",
+                dashboards=[
+                    dashboard.Dashboard(),
+                ],
+                next_page_token="ghi",
             ),
             dashboards_service.ListDashboardsResponse(
-                dashboards=[dashboard.Dashboard(), dashboard.Dashboard(),],
+                dashboards=[
+                    dashboard.Dashboard(),
+                    dashboard.Dashboard(),
+                ],
             ),
             RuntimeError,
         )
@@ -1034,20 +1105,29 @@ async def test_list_dashboards_async_pager():
                 next_page_token="abc",
             ),
             dashboards_service.ListDashboardsResponse(
-                dashboards=[], next_page_token="def",
+                dashboards=[],
+                next_page_token="def",
             ),
             dashboards_service.ListDashboardsResponse(
-                dashboards=[dashboard.Dashboard(),], next_page_token="ghi",
+                dashboards=[
+                    dashboard.Dashboard(),
+                ],
+                next_page_token="ghi",
             ),
             dashboards_service.ListDashboardsResponse(
-                dashboards=[dashboard.Dashboard(), dashboard.Dashboard(),],
+                dashboards=[
+                    dashboard.Dashboard(),
+                    dashboard.Dashboard(),
+                ],
             ),
             RuntimeError,
         )
-        async_pager = await client.list_dashboards(request={},)
+        async_pager = await client.list_dashboards(
+            request={},
+        )
         assert async_pager.next_page_token == "abc"
         responses = []
-        async for response in async_pager:
+        async for response in async_pager:  # pragma: no branch
             responses.append(response)
 
         assert len(responses) == 6
@@ -1075,29 +1155,43 @@ async def test_list_dashboards_async_pages():
                 next_page_token="abc",
             ),
             dashboards_service.ListDashboardsResponse(
-                dashboards=[], next_page_token="def",
+                dashboards=[],
+                next_page_token="def",
             ),
             dashboards_service.ListDashboardsResponse(
-                dashboards=[dashboard.Dashboard(),], next_page_token="ghi",
+                dashboards=[
+                    dashboard.Dashboard(),
+                ],
+                next_page_token="ghi",
             ),
             dashboards_service.ListDashboardsResponse(
-                dashboards=[dashboard.Dashboard(), dashboard.Dashboard(),],
+                dashboards=[
+                    dashboard.Dashboard(),
+                    dashboard.Dashboard(),
+                ],
             ),
             RuntimeError,
         )
         pages = []
-        async for page_ in (await client.list_dashboards(request={})).pages:
+        async for page_ in (
+            await client.list_dashboards(request={})
+        ).pages:  # pragma: no branch
             pages.append(page_)
         for page_, token in zip(pages, ["abc", "def", "ghi", ""]):
             assert page_.raw_page.next_page_token == token
 
 
 @pytest.mark.parametrize(
-    "request_type", [dashboards_service.GetDashboardRequest, dict,]
+    "request_type",
+    [
+        dashboards_service.GetDashboardRequest,
+        dict,
+    ],
 )
 def test_get_dashboard(request_type, transport: str = "grpc"):
     client = DashboardsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1131,7 +1225,8 @@ def test_get_dashboard_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DashboardsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1147,7 +1242,8 @@ async def test_get_dashboard_async(
     transport: str = "grpc_asyncio", request_type=dashboards_service.GetDashboardRequest
 ):
     client = DashboardsServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1159,7 +1255,9 @@ async def test_get_dashboard_async(
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             dashboard.Dashboard(
-                name="name_value", display_name="display_name_value", etag="etag_value",
+                name="name_value",
+                display_name="display_name_value",
+                etag="etag_value",
             )
         )
         response = await client.get_dashboard(request)
@@ -1182,13 +1280,15 @@ async def test_get_dashboard_async_from_dict():
 
 
 def test_get_dashboard_field_headers():
-    client = DashboardsServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DashboardsServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = dashboards_service.GetDashboardRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.get_dashboard), "__call__") as call:
@@ -1202,7 +1302,10 @@ def test_get_dashboard_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1215,7 +1318,7 @@ async def test_get_dashboard_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = dashboards_service.GetDashboardRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.get_dashboard), "__call__") as call:
@@ -1229,15 +1332,23 @@ async def test_get_dashboard_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.parametrize(
-    "request_type", [dashboards_service.DeleteDashboardRequest, dict,]
+    "request_type",
+    [
+        dashboards_service.DeleteDashboardRequest,
+        dict,
+    ],
 )
 def test_delete_dashboard(request_type, transport: str = "grpc"):
     client = DashboardsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1263,7 +1374,8 @@ def test_delete_dashboard_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DashboardsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1280,7 +1392,8 @@ async def test_delete_dashboard_async(
     request_type=dashboards_service.DeleteDashboardRequest,
 ):
     client = DashboardsServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1308,13 +1421,15 @@ async def test_delete_dashboard_async_from_dict():
 
 
 def test_delete_dashboard_field_headers():
-    client = DashboardsServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DashboardsServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = dashboards_service.DeleteDashboardRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.delete_dashboard), "__call__") as call:
@@ -1328,7 +1443,10 @@ def test_delete_dashboard_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1341,7 +1459,7 @@ async def test_delete_dashboard_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = dashboards_service.DeleteDashboardRequest()
 
-    request.name = "name/value"
+    request.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.delete_dashboard), "__call__") as call:
@@ -1355,15 +1473,23 @@ async def test_delete_dashboard_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "name=name/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "name=name_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.parametrize(
-    "request_type", [dashboards_service.UpdateDashboardRequest, dict,]
+    "request_type",
+    [
+        dashboards_service.UpdateDashboardRequest,
+        dict,
+    ],
 )
 def test_update_dashboard(request_type, transport: str = "grpc"):
     client = DashboardsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1397,7 +1523,8 @@ def test_update_dashboard_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DashboardsServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1414,7 +1541,8 @@ async def test_update_dashboard_async(
     request_type=dashboards_service.UpdateDashboardRequest,
 ):
     client = DashboardsServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1426,7 +1554,9 @@ async def test_update_dashboard_async(
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             dashboard.Dashboard(
-                name="name_value", display_name="display_name_value", etag="etag_value",
+                name="name_value",
+                display_name="display_name_value",
+                etag="etag_value",
             )
         )
         response = await client.update_dashboard(request)
@@ -1449,13 +1579,15 @@ async def test_update_dashboard_async_from_dict():
 
 
 def test_update_dashboard_field_headers():
-    client = DashboardsServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DashboardsServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = dashboards_service.UpdateDashboardRequest()
 
-    request.dashboard.name = "dashboard.name/value"
+    request.dashboard.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.update_dashboard), "__call__") as call:
@@ -1469,9 +1601,10 @@ def test_update_dashboard_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "dashboard.name=dashboard.name/value",) in kw[
-        "metadata"
-    ]
+    assert (
+        "x-goog-request-params",
+        "dashboard.name=name_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1484,7 +1617,7 @@ async def test_update_dashboard_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = dashboards_service.UpdateDashboardRequest()
 
-    request.dashboard.name = "dashboard.name/value"
+    request.dashboard.name = "name_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.update_dashboard), "__call__") as call:
@@ -1498,9 +1631,10 @@ async def test_update_dashboard_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "dashboard.name=dashboard.name/value",) in kw[
-        "metadata"
-    ]
+    assert (
+        "x-goog-request-params",
+        "dashboard.name=name_value",
+    ) in kw["metadata"]
 
 
 def test_credentials_transport_error():
@@ -1510,7 +1644,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = DashboardsServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1530,7 +1665,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = DashboardsServiceClient(client_options=options, transport=transport,)
+        client = DashboardsServiceClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -1546,7 +1684,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = DashboardsServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1589,10 +1728,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = DashboardsServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = DashboardsServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.DashboardsServiceGrpcTransport,)
+    client = DashboardsServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.DashboardsServiceGrpcTransport,
+    )
 
 
 def test_dashboards_service_base_transport_error():
@@ -1630,6 +1787,14 @@ def test_dashboards_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_dashboards_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1641,7 +1806,8 @@ def test_dashboards_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.DashboardsServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1794,24 +1960,40 @@ def test_dashboards_service_grpc_transport_client_cert_source_for_mtls(transport
             )
 
 
-def test_dashboards_service_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_dashboards_service_host_no_port(transport_name):
     client = DashboardsServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="monitoring.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "monitoring.googleapis.com:443"
+    assert client.transport._host == ("monitoring.googleapis.com:443")
 
 
-def test_dashboards_service_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_dashboards_service_host_with_port(transport_name):
     client = DashboardsServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="monitoring.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "monitoring.googleapis.com:8000"
+    assert client.transport._host == ("monitoring.googleapis.com:8000")
 
 
 def test_dashboards_service_grpc_transport_channel():
@@ -1819,7 +2001,8 @@ def test_dashboards_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.DashboardsServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1831,7 +2014,8 @@ def test_dashboards_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.DashboardsServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1942,7 +2126,8 @@ def test_alert_policy_path():
     project = "squid"
     alert_policy = "clam"
     expected = "projects/{project}/alertPolicies/{alert_policy}".format(
-        project=project, alert_policy=alert_policy,
+        project=project,
+        alert_policy=alert_policy,
     )
     actual = DashboardsServiceClient.alert_policy_path(project, alert_policy)
     assert expected == actual
@@ -1964,7 +2149,8 @@ def test_dashboard_path():
     project = "oyster"
     dashboard = "nudibranch"
     expected = "projects/{project}/dashboards/{dashboard}".format(
-        project=project, dashboard=dashboard,
+        project=project,
+        dashboard=dashboard,
     )
     actual = DashboardsServiceClient.dashboard_path(project, dashboard)
     assert expected == actual
@@ -2004,7 +2190,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "scallop"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = DashboardsServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -2022,7 +2210,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "squid"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = DashboardsServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -2040,7 +2230,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "whelk"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = DashboardsServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -2060,7 +2252,8 @@ def test_common_location_path():
     project = "oyster"
     location = "nudibranch"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = DashboardsServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -2085,7 +2278,8 @@ def test_client_with_default_client_info():
         transports.DashboardsServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = DashboardsServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -2094,7 +2288,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = DashboardsServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -2102,7 +2297,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = DashboardsServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
